package org.eclipse.osgi.util;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.StringTokenizer;

/* loaded from: org_eclipse_osgi_util.jar:org/eclipse/osgi/util/ManifestElement.class */
public class ManifestElement {
    private static final String MANIFEST_INVALID_SPACE = "The manifest line \"{0}\" has an invalid leading space '' '' character.";
    private static final String MANIFEST_INVALID_LINE_NOCOLON = "The manifest line \"{0}\" is invalid; it has no colon '':'' character after the header key.";
    private static final String MANIFEST_INVALID_HEADER_EXCEPTION = "Invalid manifest header {0}: \"{1}\"";
    protected String value;
    protected String[] valueComponents;
    protected Hashtable attributes;
    protected Hashtable directives;

    protected ManifestElement() {
    }

    public String getValue() {
        return this.value;
    }

    public String[] getValueComponents() {
        return this.valueComponents;
    }

    public String getAttribute(String key) {
        return getTableValue(this.attributes, key);
    }

    public String[] getAttributes(String key) {
        return getTableValues(this.attributes, key);
    }

    public Enumeration getKeys() {
        return getTableKeys(this.attributes);
    }

    protected void addAttribute(String key, String value) {
        this.attributes = addTableValue(this.attributes, key, value);
    }

    public String getDirective(String key) {
        return getTableValue(this.directives, key);
    }

    public String[] getDirectives(String key) {
        return getTableValues(this.directives, key);
    }

    public Enumeration getDirectiveKeys() {
        return getTableKeys(this.directives);
    }

    protected void addDirective(String key, String value) {
        this.directives = addTableValue(this.directives, key, value);
    }

    private String getTableValue(Hashtable table, String key) {
        Object result;
        if (table == null || (result = table.get(key)) == null) {
            return null;
        }
        if (result instanceof String) {
            return (String) result;
        }
        ArrayList valueList = (ArrayList) result;
        return (String) valueList.get(valueList.size() - 1);
    }

    private String[] getTableValues(Hashtable table, String key) {
        Object result;
        if (table == null || (result = table.get(key)) == null) {
            return null;
        }
        if (result instanceof String) {
            return new String[]{(String) result};
        }
        ArrayList valueList = (ArrayList) result;
        return (String[]) valueList.toArray(new String[valueList.size()]);
    }

    private Enumeration getTableKeys(Hashtable table) {
        if (table == null) {
            return null;
        }
        return table.keys();
    }

    private Hashtable addTableValue(Hashtable table, String key, String value) {
        ArrayList newList;
        if (table == null) {
            table = new Hashtable(7);
        }
        Object curValue = table.get(key);
        if (curValue != null) {
            if (curValue instanceof ArrayList) {
                newList = (ArrayList) curValue;
            } else {
                newList = new ArrayList(5);
                newList.add(curValue);
            }
            newList.add(value);
            table.put(key, newList);
        } else {
            table.put(key, value);
        }
        return table;
    }

    /* JADX WARN: Code restructure failed: missing block: B:54:0x0224, code lost:
    
        r0.add(r0);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static org.eclipse.osgi.util.ManifestElement[] parseHeader(java.lang.String r6, java.lang.String r7) throws org.osgi.framework.BundleException {
        /*
            Method dump skipped, instructions count: 619
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: org.eclipse.osgi.util.ManifestElement.parseHeader(java.lang.String, java.lang.String):org.eclipse.osgi.util.ManifestElement[]");
    }

    public static String[] getArrayFromList(String stringList) {
        String[] result = getArrayFromList(stringList, ",");
        if (result.length == 0) {
            return null;
        }
        return result;
    }

    public static String[] getArrayFromList(String stringList, String separator) {
        if (stringList == null || stringList.trim().length() == 0) {
            return new String[0];
        }
        ArrayList list = new ArrayList();
        StringTokenizer tokens = new StringTokenizer(stringList, separator);
        while (tokens.hasMoreTokens()) {
            String token = tokens.nextToken().trim();
            if (token.length() != 0) {
                list.add(token);
            }
        }
        return (String[]) list.toArray(new String[list.size()]);
    }

    /* JADX WARN: Code restructure failed: missing block: B:38:0x0058, code lost:
    
        if (r12 != false) goto L44;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x005b, code lost:
    
        r8.put(r10, r0.toString().trim());
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.util.Map parseBundleManifest(java.io.InputStream r7, java.util.Map r8) throws java.io.IOException, org.osgi.framework.BundleException {
        /*
            Method dump skipped, instructions count: 271
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: org.eclipse.osgi.util.ManifestElement.parseBundleManifest(java.io.InputStream, java.util.Map):java.util.Map");
    }

    public String toString() {
        Enumeration attrKeys = getKeys();
        Enumeration directiveKeys = getDirectiveKeys();
        if (attrKeys == null && directiveKeys == null) {
            return this.value;
        }
        StringBuffer result = new StringBuffer(this.value);
        if (attrKeys != null) {
            while (attrKeys.hasMoreElements()) {
                String key = (String) attrKeys.nextElement();
                addValues(false, key, getAttributes(key), result);
            }
        }
        if (directiveKeys != null) {
            while (directiveKeys.hasMoreElements()) {
                String key2 = (String) directiveKeys.nextElement();
                addValues(true, key2, getDirectives(key2), result);
            }
        }
        return result.toString();
    }

    private void addValues(boolean directive, String key, String[] values, StringBuffer result) {
        if (values == null) {
            return;
        }
        for (String str : values) {
            result.append(';').append(key);
            if (directive) {
                result.append(':');
            }
            result.append("=\"").append(str).append('\"');
        }
    }
}
